tsseg.algorithms.igts package
=============================

Top-down recursive splitting at max information gain using histogram discretisation.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised
| **Scope:** multivariate only

**Implementation:** Adapted from aeon. BSD 3-Clause.

**Reference:** Sadri, Ren & Salim (2017), PMC.

Submodules
----------

tsseg.algorithms.igts.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.igts.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.igts
   :members:
   :show-inheritance:
   :undoc-members:
